API Reference
=============

This section documents the complete API for the ``lineage`` library.

Core Classes
------------

Lineage
~~~~~~~

The main class for analyzing genetic relationships and shared DNA.

.. automodule:: lineage
   :members:
   :undoc-members:
   :show-inheritance:

Individual
~~~~~~~~~~

Represents an individual with genetic data for analysis.

.. automodule:: lineage.individual
   :members:
   :undoc-members:
   :show-inheritance:

Data Generation
---------------

lineage.generator
~~~~~~~~~~~~~~~~~

Utilities for generating synthetic genetic data for related individuals.

.. automodule:: lineage.generator
   :members:
   :undoc-members:
   :show-inheritance:

Data Resources
--------------

lineage.resources
~~~~~~~~~~~~~~~~~

Resource management for genetic maps and reference data.

.. automodule:: lineage.resources
   :members:
   :undoc-members:
   :show-inheritance:

Visualization
-------------

lineage.visualization
~~~~~~~~~~~~~~~~~~~~~

Functions for visualizing shared DNA segments.

.. automodule:: lineage.visualization
   :members:
   :undoc-members:
   :show-inheritance:
